@@ -22,13 +22,14 @@ import os
 import webbrowser
 
 from six.moves import configparser
-import yaml
 
 from rally.cli import cliutils
 from rally.cli import envutils
 from rally.common import fileutils
 from rally.common.i18n import _
 from rally.common import logging
+from rally.common import yamlutils as yaml
+from rally import exceptions
 from rally import plugins
 
 
@@ -112,9 +113,9 @@ class VerifyCommands(object):
                    help="Not to set the created verifier as the default "
                         "verifier for future operations.")
     @plugins.ensure_plugins_are_loaded
-    def create_verifier(self, api, name, vtype, namespace="",
-                        source=None, version="master", system_wide=False,
-                        extra=None, do_use=True):
+    def create_verifier(self, api, name, vtype, namespace="", source=None,
+                        version=None, system_wide=False, extra=None,
+                        do_use=True):
         """Create a verifier."""
         verifier_uuid = api.verifier.create(
             name, vtype=vtype, namespace=namespace, source=source,
@@ -182,7 +183,8 @@ class VerifyCommands(object):
             fields.append("Venv location")
             formatters["Venv location"] = lambda v: v.manager.venv_dir
         cliutils.print_dict(verifier, fields=fields, formatters=formatters,
-                            normalize_field_names=True)
+                            normalize_field_names=True, print_header=False,
+                            table_label="Verifier")
         print(_("Attention! All you do in the verifier repository or "
                 "verifier virtual environment, you do it at your own risk!"))
 
@@ -326,7 +328,7 @@ class VerifyCommands(object):
     @cliutils.args("--pattern", dest="pattern", type=str, required=False,
                    help="Pattern which will be used for matching. Can be a "
                         "regexp or a verifier-specific entity (for example, "
-                        "in case of Tempest you can specify 'set=smoke'.")
+                        "in case of Tempest you can specify 'set=smoke').")
     @envutils.with_default_verifier_id()
     @plugins.ensure_plugins_are_loaded
     def list_verifier_tests(self, api, verifier_id=None, pattern=""):
@@ -377,6 +379,16 @@ class VerifyCommands(object):
                     "verifier extension, using command `rally verify "
                     "add-verifier-ext`."))
 
+    def _print_details_after_run(self, results):
+        failures = results.filter_tests("fail").values()
+        if failures:
+            h_text = "Failed %d %s - output below:" % (
+                len(failures), "tests" if len(failures) > 1 else "test")
+            self._print_failures(h_text, failures, "=")
+        else:
+            print(_("\nCongratulations! Verification doesn't have failed "
+                    "tests! :)"))
+
     @cliutils.help_group("verifier-ext")
     @cliutils.args("--id", dest="verifier_id", type=str,
                    help="Verifier name or UUID. " + LIST_VERIFIERS_HINT)
@@ -399,11 +411,12 @@ class VerifyCommands(object):
     @cliutils.args("--pattern", dest="pattern", type=str, required=False,
                    help="Pattern which will be used for running tests. Can be "
                         "a regexp or a verifier-specific entity (for example, "
-                        "in case of Tempest you can specify 'set=smoke'.")
+                        "in case of Tempest you can specify 'set=smoke').")
     @cliutils.args("--concurrency", dest="concur", type=int, metavar="<N>",
                    required=False,
-                   help="How many processes to use to run verifier tests. "
-                        "The default value (0) auto-detects your CPU count.")
+                   help="How many processes to be used for running verifier "
+                        "tests. The default value (0) auto-detects your CPU "
+                        "count.")
     @cliutils.args("--load-list", dest="load_list", type=str, metavar="<path>",
                    required=False,
                    help="Path to a file with a list of tests to run.")
@@ -466,18 +479,16 @@ class VerifyCommands(object):
             ("skip_list", skip_list), ("xfail_list", xfail_list),
             ("concurrency", concur)) if value}
 
-        verification, results = api.verification.start(verifier_id, deployment,
-                                                       tags=tags, **run_args)
+        try:
+            verification, results = api.verification.start(
+                verifier_id, deployment, tags=tags, **run_args)
+        except exceptions.DeploymentNotFinishedStatus as e:
+            print(_("Cannot start a verefication on "
+                    "unfinished deployment: %s") % e)
+            return 1
 
         if detailed:
-            failures = results.filter_tests("fail").values()
-            if failures:
-                h_text = "Failed %d %s - output below:" % (
-                    len(failures), "tests" if len(failures) > 1 else "test")
-                self._print_failures(h_text, failures, "=")
-            else:
-                print(_("\nCongratulations! Verification doesn't have failed "
-                        "tests! :)"))
+            self._print_details_after_run(results)
 
         self._print_totals(results.totals)
 
@@ -505,16 +516,40 @@ class VerifyCommands(object):
                    help="Deployment name or UUID. " + LIST_DEPLOYMENTS_HINT)
     @cliutils.args("--failed", dest="failed", required=False,
                    help="Rerun only failed tests.", action="store_true")
+    @cliutils.args("--tag", nargs="+", dest="tags", type=str, required=False,
+                   help="Mark verification with a tag or a few tags.")
+    @cliutils.args("--concurrency", dest="concur", type=int, metavar="<N>",
+                   required=False,
+                   help="How many processes to be used for running verifier "
+                        "tests. The default value (0) auto-detects your CPU "
+                        "count.")
+    @cliutils.args("--detailed", dest="detailed", action="store_true",
+                   required=False,
+                   help="Show verification details such as errors of failed "
+                        "tests.")
+    @cliutils.args("--no-use", dest="do_use", action="store_false",
+                   help="Not to set the finished verification as the default "
+                        "verification for future operations.")
     @envutils.with_default_verification_uuid
     @envutils.with_default_deployment(cli_arg_name="deployment-id")
     @plugins.ensure_plugins_are_loaded
-    def rerun(self, api, verification_uuid=None, deployment=None,
-              failed=False):
+    def rerun(self, api, verification_uuid=None, deployment=None, tags=None,
+              concur=None, failed=False, detailed=False, do_use=True):
         """Rerun tests from a verification for a specific deployment."""
         verification, results = api.verification.rerun(verification_uuid,
-                                                       deployment, failed)
+                                                       deployment=deployment,
+                                                       failed=failed,
+                                                       tags=tags,
+                                                       concur=concur)
+        if detailed:
+            self._print_details_after_run(results)
+
         self._print_totals(results.totals)
-        print(_("Verification UUID: %s.") % verification.uuid)
+
+        if do_use:
+            self.use(api, verification.uuid)
+        else:
+            print(_("Verification UUID: %s.") % verification.uuid)
 
     @cliutils.help_group("verification")
     @cliutils.args("--uuid", dest="verification_uuid", type=str,
@@ -658,9 +693,9 @@ class VerifyCommands(object):
                         "command." % ", ".join(DEFAULT_REPORT_TYPES))
     @cliutils.args("--to", dest="output_dest", type=str,
                    metavar="<dest>", required=False,
-                   help="Report destination. Can be a path to a file (in case"
-                        " of HTML, JSON types) to save the report to or "
-                        "a connection string. It depends on report type.")
+                   help="Report destination. Can be a path to a file (in case "
+                        "of HTML, JSON, etc. types) to save the report to or "
+                        "a connection string. It depends on the report type.")
     @cliutils.args("--open", dest="open_it", action="store_true",
                    required=False, help="Open the output file in a browser.")
     @envutils.with_default_verification_uuid
@@ -668,7 +703,6 @@ class VerifyCommands(object):
     def report(self, api, verification_uuid=None, output_type=None,
                output_dest=None, open_it=None):
         """Generate a report for a verification or a few verifications."""
-
         if not isinstance(verification_uuid, list):
             verification_uuid = [verification_uuid]
 
