@@ -20,13 +20,8 @@ from oslo_config import cfg
 from saharaclient.api import base as saharaclient_base
 
 from rally.common import logging
-from rally.common.plugin import discover
-from rally.common import utils
+from rally import consts
 from rally.plugins.openstack.cleanup import base
-from rally.plugins.openstack.scenarios.cinder import utils as cinder_utils
-from rally.plugins.openstack.scenarios.fuel import utils as futils
-from rally.plugins.openstack.scenarios.keystone import utils as kutils
-from rally.plugins.openstack.scenarios.nova import utils as nova_utils
 from rally.plugins.openstack.services.identity import identity
 from rally.plugins.openstack.wrappers import glance as glance_wrapper
 from rally.task import utils as task_utils
@@ -135,7 +130,8 @@ class SenlinMixin(base.ResourceManager):
         return getattr(self._manager(), "delete_%s" % res_name)(self.id())
 
 
-@base.resource("senlin", "clusters", order=next(_senlin_order))
+@base.resource("senlin", "clusters",
+               admin_required=True, order=next(_senlin_order))
 class SenlinCluster(SenlinMixin):
     """Resource class for Senlin Cluster."""
 
@@ -156,28 +152,7 @@ _nova_order = get_order(200)
 class NovaServer(base.ResourceManager):
     def list(self):
         """List all servers."""
-
-        if hasattr(self._manager().api, "api_version"):
-            # NOTE(andreykurilin): novaclient v2.27.0 includes ability to
-            #   return all servers(see https://review.openstack.org/#/c/217101
-            #   for more details). This release can be identified by presence
-            #   of "api_version" property of ``novaclient.client.Client`` cls.
-            return self._manager().list(limit=-1)
-        else:
-            # FIXME(andreykurilin): Remove code below, when minimum version of
-            #   novaclient in requirements will allow it.
-            # NOTE(andreykurilin): Nova API returns only limited number(
-            #   'osapi_max_limit' option in nova.conf) of servers, so we need
-            #   to use 'marker' option to list all pages of servers.
-            result = []
-            marker = None
-            while True:
-                servers = self._manager().list(marker=marker)
-                if not servers:
-                    break
-                result.extend(servers)
-                marker = servers[-1].id
-            return result
+        return self._manager().list(limit=-1)
 
     def delete(self):
         if getattr(self.raw_resource, "OS-EXT-STS:locked", False):
@@ -188,16 +163,14 @@ class NovaServer(base.ResourceManager):
 @base.resource("nova", "server_groups", order=next(_nova_order),
                tenant_resource=True)
 class NovaServerGroups(base.ResourceManager):
-    def list(self):
-        return [r for r in self._manager().list()
-                if utils.name_matches_object(r.name, nova_utils.NovaScenario)]
+    pass
 
 
 @base.resource("nova", "floating_ips", order=next(_nova_order))
 class NovaFloatingIPs(SynchronizedDeletion, base.ResourceManager):
 
     def name(self):
-        return None
+        return self.raw_resource.pool
 
 
 @base.resource("nova", "keypairs", order=next(_nova_order))
@@ -223,9 +196,7 @@ class NovaQuotas(QuotaMixin, base.ResourceManager):
 @base.resource("nova", "flavors", order=next(_nova_order),
                admin_required=True, perform_for_admin_only=True)
 class NovaFlavors(base.ResourceManager):
-    def list(self):
-        return [r for r in self._manager().list()
-                if utils.name_matches_object(r.name, nova_utils.NovaScenario)]
+    pass
 
     def is_deleted(self):
         try:
@@ -246,11 +217,6 @@ class NovaFloatingIpsBulk(SynchronizedDeletion, base.ResourceManager):
     def name(self):
         return None
 
-    def list(self):
-        return [floating_ip for floating_ip in self._manager().list()
-                if utils.name_matches_object(floating_ip.pool,
-                                             nova_utils.NovaScenario)]
-
 
 @base.resource("nova", "networks", order=next(_nova_order),
                admin_required=True, tenant_resource=True)
@@ -259,26 +225,11 @@ class NovaNetworks(SynchronizedDeletion, base.ResourceManager):
     def name(self):
         return self.raw_resource.label
 
-    def list(self):
-        # NOTE(stpierre): any plugin can create a nova network via the
-        # network wrapper, and that network's name will be created
-        # according to its owner's random name generation
-        # parameters. so we need to check if there are nova networks
-        # whose name pattern matches those of any loaded plugin that
-        # implements RandomNameGeneratorMixin
-        classes = list(discover.itersubclasses(utils.RandomNameGeneratorMixin))
-        return [net for net in self._manager().list()
-                if utils.name_matches_object(net.label, *classes)]
-
 
 @base.resource("nova", "aggregates", order=next(_nova_order),
                admin_required=True, perform_for_admin_only=True)
 class NovaAggregate(SynchronizedDeletion, base.ResourceManager):
 
-    def list(self):
-        return [r for r in self._manager().list()
-                if utils.name_matches_object(r.name, nova_utils.NovaScenario)]
-
     def delete(self):
         for host in self.raw_resource.hosts:
             self.raw_resource.remove_host(host)
@@ -346,7 +297,7 @@ class NeutronMixin(SynchronizedDeletion, base.ResourceManager):
         return self.raw_resource["id"]
 
     def name(self):
-        return self.raw_resource.get("name", "")
+        return self.raw_resource["name"]
 
     def delete(self):
         delete_method = getattr(self._manager(), "delete_%s" % self._resource)
@@ -407,10 +358,33 @@ class NeutronV2Loadbalancer(NeutronLbaasV2Mixin):
         return False
 
 
+# NOTE(andreykurilin): There are scenarios which uses unified way for creating
+#   and associating floating ips. They do not care about nova-net and neutron.
+#   We should clean floating IPs for them, but hardcoding "neutron.floatingip"
+#   cleanup resource should not work in case of Nova-Net.
+#   Since we are planning to abandon support of Nova-Network in next rally
+#   release, let's apply dirty workaround to handle all resources.
+@base.resource("neutron", "floatingip", order=next(_neutron_order),
+               tenant_resource=True)
+class NeutronFloatingIP(NeutronMixin):
+    def name(self):
+        return base.NoName(self._resource)
+
+    def list(self):
+        if consts.ServiceType.NETWORK not in self.user.services():
+            return []
+        return super(NeutronFloatingIP, self).list()
+
+
 @base.resource("neutron", "port", order=next(_neutron_order),
                tenant_resource=True)
 class NeutronPort(NeutronMixin):
 
+    def name(self):
+        # TODO(andreykurilin): return NoName instance only in case of "name"
+        #   field is missed
+        return base.NoName(self._resource)
+
     def delete(self):
         if (self.raw_resource["device_owner"] in
             ("network:router_interface",
@@ -429,12 +403,6 @@ class NeutronPort(NeutronMixin):
                           % self.id())
 
 
-@base.resource("neutron", "router", order=next(_neutron_order),
-               tenant_resource=True)
-class NeutronRouter(NeutronMixin):
-    pass
-
-
 @base.resource("neutron", "subnet", order=next(_neutron_order),
                tenant_resource=True)
 class NeutronSubnet(NeutronMixin):
@@ -447,9 +415,9 @@ class NeutronNetwork(NeutronMixin):
     pass
 
 
-@base.resource("neutron", "floatingip", order=next(_neutron_order),
+@base.resource("neutron", "router", order=next(_neutron_order),
                tenant_resource=True)
-class NeutronFloatingIP(NeutronMixin):
+class NeutronRouter(NeutronMixin):
     pass
 
 
@@ -486,10 +454,7 @@ class CinderVolumeBackup(base.ResourceManager):
 @base.resource("cinder", "volume_types", order=next(_cinder_order),
                admin_required=True, perform_for_admin_only=True)
 class CinderVolumeType(base.ResourceManager):
-    def list(self):
-        return [r for r in self._manager().list()
-                if utils.name_matches_object(r.name,
-                                             cinder_utils.CinderScenario)]
+    pass
 
 
 @base.resource("cinder", "volume_snapshots", order=next(_cinder_order),
@@ -861,11 +826,6 @@ class FuelEnvironment(base.ResourceManager):
     def is_deleted(self):
         return not self._manager().get(self.id())
 
-    def list(self):
-        return [env for env in self._manager().list()
-                if utils.name_matches_object(env["name"],
-                                             futils.FuelScenario)]
-
 
 # WATCHER
 
@@ -926,11 +886,8 @@ class KeystoneMixin(SynchronizedDeletion):
         delete_method(self.id())
 
     def list(self):
-        # TODO(boris-42): We should use such stuff in all list commands.
         resources = self._resource + "s"
-        list_method = getattr(self._manager(), "list_%s" % resources)
-        return [r for r in list_method()
-                if utils.name_matches_object(r.name, kutils.KeystoneScenario)]
+        return getattr(self._manager(), "list_%s" % resources)()
 
 
 @base.resource("keystone", "user", order=next(_keystone_order),
