@@ -180,6 +180,26 @@ class TaskCommandsTestCase(test.TestCase):
         mock_detailed.assert_called_once_with(self.fake_api,
                                               task_id="some_new_uuid")
 
+    @mock.patch("rally.cli.commands.task.os.path.isfile", return_value=True)
+    @mock.patch("rally.cli.commands.task.TaskCommands.detailed")
+    @mock.patch("rally.cli.commands.task.TaskCommands._load_task",
+                return_value="some_config")
+    def test_start_on_unfinished_deployment(
+            self, mock__load_task, mock_detailed, mock_os_path_isfile):
+        deployment_id = "e0617de9-77d1-4875-9b49-9d5789e29f20"
+        deployment_name = "xxx_name"
+        task_path = "path_to_config.json"
+        self.fake_api.task.create.return_value = fakes.FakeTask(
+            uuid="some_new_uuid", tag="tag")
+
+        exc = exceptions.DeploymentNotFinishedStatus(
+            name=deployment_name,
+            uuid=deployment_id,
+            status=consts.DeployStatus.DEPLOY_INIT)
+        self.fake_api.task.create.side_effect = exc
+        self.assertEqual(1, self.task.start(self.fake_api, task_path,
+                                            deployment="any", tag="some_tag"))
+
     @mock.patch("rally.cli.commands.task.os.path.isfile", return_value=True)
     @mock.patch("rally.cli.commands.task.TaskCommands.detailed")
     @mock.patch("rally.cli.commands.task.TaskCommands._load_task",
@@ -325,7 +345,7 @@ class TaskCommandsTestCase(test.TestCase):
         value = {
             "id": "task",
             "uuid": test_uuid,
-            "status": consts.TaskStatus.FAILED,
+            "status": consts.TaskStatus.CRASHED,
             "results": [],
             "verification_log": json.dumps({"etype": "error_type",
                                             "msg": "error_message",
@@ -337,11 +357,11 @@ class TaskCommandsTestCase(test.TestCase):
         self.task.detailed(self.fake_api, test_uuid)
         verification = yaml.safe_load(value["verification_log"])
         if debug:
-            expected_calls = [mock.call("Task test_task_id: failed"),
+            expected_calls = [mock.call("Task test_task_id: crashed"),
                               mock.call("%s" % verification["trace"])]
             mock_stdout.write.assert_has_calls(expected_calls, any_order=True)
         else:
-            expected_calls = [mock.call("Task test_task_id: failed"),
+            expected_calls = [mock.call("Task test_task_id: crashed"),
                               mock.call("%s" % verification["etype"]),
                               mock.call("%s" % verification["msg"]),
                               mock.call("\nFor more details run:\nrally "
@@ -381,16 +401,20 @@ class TaskCommandsTestCase(test.TestCase):
     @mock.patch("json.dumps")
     def test_results(self, mock_json_dumps):
         task_id = "foo_task_id"
+        created_at = dt.datetime(2017, 2, 6, 1, 1, 1)
         data = [
             {"key": "foo_key", "data": {"raw": "foo_raw", "sla": [],
                                         "hooks": [],
                                         "load_duration": 1.0,
-                                        "full_duration": 2.0}}
+                                        "full_duration": 2.0},
+             "created_at": created_at}
         ]
         result = map(lambda x: {"key": x["key"],
                                 "result": x["data"]["raw"],
                                 "load_duration": x["data"]["load_duration"],
                                 "full_duration": x["data"]["full_duration"],
+                                "created_at": x.get("created_at").strftime(
+                                    "%Y-%d-%mT%H:%M:%S"),
                                 "hooks": x["data"]["hooks"],
                                 "sla": x["data"]["sla"]}, data)
         fake_task = fakes.FakeTask({"status": consts.TaskStatus.FINISHED})
@@ -408,7 +432,7 @@ class TaskCommandsTestCase(test.TestCase):
     @mock.patch("rally.cli.commands.task.sys.stdout")
     def test_results_no_data(self, mock_stdout):
         task_id = "foo_task_id"
-        fake_task = fakes.FakeTask({"status": consts.TaskStatus.FAILED})
+        fake_task = fakes.FakeTask({"status": consts.TaskStatus.CRASHED})
         self.fake_api.task.get.return_value = fake_task
 
         self.assertEqual(1, self.task.results(self.fake_api, task_id))
@@ -417,7 +441,7 @@ class TaskCommandsTestCase(test.TestCase):
 
         expected_out = ("Task status is %s. Results "
                         "available when it is one of %s.") % (
-            consts.TaskStatus.FAILED,
+            consts.TaskStatus.CRASHED,
             ", ".join((consts.TaskStatus.FINISHED,
                        consts.TaskStatus.ABORTED)))
         mock_stdout.write.assert_has_calls([mock.call(expected_out)])
@@ -559,19 +583,22 @@ class TaskCommandsTestCase(test.TestCase):
              "data": {"raw": "foo_raw", "sla": "foo_sla",
                       "hooks": "foo_hooks",
                       "load_duration": 0.1,
-                      "full_duration": 1.2}},
+                      "full_duration": 1.2},
+             "created_at": "2017-06-02T07:33:04"},
             {"key": {"name": "class.test", "pos": 0},
              "data": {"raw": "bar_raw", "sla": "bar_sla",
                       "hooks": "bar_hooks",
                       "load_duration": 2.1,
-                      "full_duration": 2.2}}]
+                      "full_duration": 2.2},
+             "created_at": "2017-06-02T07:33:04"}]
 
         results = [{"key": x["key"],
                     "result": x["data"]["raw"],
                     "sla": x["data"]["sla"],
                     "hooks": x["data"]["hooks"],
                     "load_duration": x["data"]["load_duration"],
-                    "full_duration": x["data"]["full_duration"]}
+                    "full_duration": x["data"]["full_duration"],
+                    "created_at": x["created_at"]}
                    for x in data]
         mock_results = mock.Mock(return_value=data)
         self.fake_api.task.get.return_value.get_results = mock_results
@@ -629,12 +656,14 @@ class TaskCommandsTestCase(test.TestCase):
              "data": {"raw": "foo_raw", "sla": "foo_sla",
                       "hooks": "foo_hooks",
                       "load_duration": 0.1,
-                      "full_duration": 1.2}},
+                      "full_duration": 1.2},
+             "created_at": "2017-06-02T07:33:04"},
             {"key": {"name": "test", "pos": 0},
              "data": {"raw": "bar_raw", "sla": "bar_sla",
                       "hooks": "bar_hooks",
                       "load_duration": 2.1,
-                      "full_duration": 2.2}}]
+                      "full_duration": 2.2},
+             "created_at": "2017-06-02T07:33:04"}]
 
         results = []
         for task_uuid in tasks:
@@ -644,7 +673,8 @@ class TaskCommandsTestCase(test.TestCase):
                                "sla": x["data"]["sla"],
                                "hooks": x["data"]["hooks"],
                                "load_duration": x["data"]["load_duration"],
-                               "full_duration": x["data"]["full_duration"]},
+                               "full_duration": x["data"]["full_duration"],
+                               "created_at": x["created_at"]},
                     data))
 
         mock_results = mock.Mock(return_value=data)
@@ -680,17 +710,20 @@ class TaskCommandsTestCase(test.TestCase):
             {"key": {"name": "test", "pos": 0},
              "data": {"raw": "foo_raw", "sla": "foo_sla",
                       "load_duration": 0.1,
-                      "full_duration": 1.2}},
+                      "full_duration": 1.2},
+             "created_at": "2017-06-02T07:33:04"},
             {"key": {"name": "test", "pos": 1},
              "data": {"raw": "bar_raw", "sla": "bar_sla",
                       "load_duration": 2.1,
-                      "full_duration": 2.2}}]
+                      "full_duration": 2.2},
+             "created_at": "2017-06-02T07:33:04"}]
 
         results = [{"key": x["key"],
                     "result": x["data"]["raw"],
                     "sla": x["data"]["sla"],
                     "load_duration": x["data"]["load_duration"],
-                    "full_duration": x["data"]["full_duration"]}
+                    "full_duration": x["data"]["full_duration"],
+                    "created_at": x["created_at"]}
                    for x in data]
 
         mock_plot.plot.return_value = "html_report"
