@@ -22,6 +22,8 @@ import six
 from rally.cli import cliutils
 from rally.cli.commands import verify
 from rally.cli import envutils
+from rally import consts
+from rally import exceptions
 from rally import plugins
 from rally.verification import reporter
 from tests.unit import fakes
@@ -115,8 +117,8 @@ class VerifyCommandsTestCase(test.TestCase):
         self.assertEqual(1, len(print_dict_calls))
 
         self.assertEqual(
-            "+----------------+----------------------------+\n"
-            "| Property       | Value                      |\n"
+            "+---------------------------------------------+\n"
+            "|                  Verifier                   |\n"
             "+----------------+----------------------------+\n"
             "| UUID           | v_uuid                     |\n"
             "| Status         | installed                  |\n"
@@ -165,18 +167,21 @@ class VerifyCommandsTestCase(test.TestCase):
     def test_configure_verifier(self, mock_exists, mock_open):
         self.verify.configure_verifier(self.fake_api, "v_id", "d_id",
                                        new_configuration="/p/a/t/h",
-                                       reconfigure=True)
+                                       reconfigure=True,
+                                       show=True)
         self.assertFalse(self.fake_api.verifier.configure.called)
 
         mock_exists.return_value = False
         self.verify.configure_verifier(self.fake_api, "v_id", "d_id",
-                                       new_configuration="/p/a/t/h")
+                                       new_configuration="/p/a/t/h",
+                                       show=True)
         self.assertFalse(self.fake_api.verifier.override_configuration.called)
 
         mock_exists.return_value = True
         mock_open.return_value = mock.mock_open(read_data="data").return_value
         self.verify.configure_verifier(self.fake_api, "v_id", "d_id",
-                                       new_configuration="/p/a/t/h")
+                                       new_configuration="/p/a/t/h",
+                                       show=True)
         mock_open.assert_called_once_with("/p/a/t/h")
         self.fake_api.verifier.override_configuration("v_id", "d_id", "data")
 
@@ -321,6 +326,20 @@ class VerifyCommandsTestCase(test.TestCase):
         self.assertFalse(self.fake_api.verification.get.called)
         self.assertFalse(mock_update_globals_file.called)
 
+    @mock.patch("rally.cli.commands.verify.os.path.exists")
+    @mock.patch("rally.cli.commands.verify.fileutils.update_globals_file")
+    def test_start_on_unfinished_deployment(self, mock_update_globals_file,
+                                            mock_exists):
+        deployment_id = "d_id"
+        deployment_name = "xxx_name"
+        exc = exceptions.DeploymentNotFinishedStatus(
+            name=deployment_name,
+            uuid=deployment_id,
+            status=consts.DeployStatus.DEPLOY_INIT)
+        self.fake_api.verification.start.side_effect = exc
+        self.assertEqual(
+            1, self.verify.start(self.fake_api, "v_id", deployment_id))
+
     @mock.patch("rally.cli.commands.verify.fileutils.update_globals_file")
     def test_use(self, mock_update_globals_file):
         self.fake_api.verification.get.return_value = mock.Mock(uuid="v_uuid")
@@ -340,9 +359,9 @@ class VerifyCommandsTestCase(test.TestCase):
                                     "failures": 0})
         self.fake_api.verification.rerun.return_value = (verification, results)
 
-        self.verify.rerun(self.fake_api, "v_uuid", "d_id", failed=True)
-        self.fake_api.verification.rerun.assert_called_once_with("v_uuid",
-                                                                 "d_id", True)
+        self.verify.rerun(self.fake_api, "v_uuid", "d_id", failed=True,)
+        self.fake_api.verification.rerun.assert_called_once_with(
+            "v_uuid", deployment="d_id", failed=True, tags=None, concur=None)
 
     def test_show(self):
         deployment_name = "Some Deploy"
